@@ -78,7 +78,8 @@ class BaseClient(Socket):
 
         try:
             response = self.session.request(method, uri, data=payload)
-        except ConnectionError: # macOS sometimes throws this error if session has idled
+        # Below error is raised when session idles for to long (typically only on macOS)
+        except requests.exceptions.ConnectionError:
             response = self.session.request(method, uri, data=payload)
 
         if response.status_code == 200:
@@ -156,26 +157,20 @@ class Client(BaseClient):
 
     Parameters
     ----------
-    api_key : str 
-        (Optional) API key generated upon creation of API endpoint on
-        kucoin.com. If no API key is given, the user cannot access functions requiring
-        account level authorization, but can access endpoints that require general auth
-        such as kline historic data.
-    api_secret : str 
-        (Optional) Secret API sequence generated upon create of API
-        endpoint on kucoin.com. See api_keydocs for info on optionality of 
+    api_key : str, optional
+        API key generated upon creation of API endpoint on kucoin.com. If no API key is given,
+        the user cannot access functions requiring account level authorization, but can access
+        endpoints that require general auth such as general market data.
+    api_secret : str, optional
+        Secret API sequence generated upon create of API endpoint on kucoin.com. 
+        See api_key docs for info on optionality of 
         variable
-    api_passphrase : str 
-        (Optional) User created API passphrase. Passphrase is 
-        created by the user during API setup on kucoin.com. See api_keydocs for 
-        info on optionality of variable
+    api_passphrase : str, optional
+        User created API passphrase. Passphrase is created by the user during API setup on 
+        kucoin.com. See api_key docs for info on optionality of variable
     sandbox : bool 
-        If sandbox = True, access a special papertrading API version
-        available for testing trading. For more details visit: https://sandbox.kucoin.com/
-        Be aware that (1) sandbox API key, secret, and passphrase are NOT the same as
-        regular kucoin API and may only be obtained from the sandbox website and (2)
-        that sandbox markets are completely seperate than kucoin's regular sites. It is
-        recommended that you not use sandbox as the data is highly corrupted.
+        If `sandbox=True`, access a special papertrading API version available for testing
+        trading. For more details visit: https://sandbox.kucoin.com/.
     """
 
     REST_API_URL = "https://api.kucoin.com"
@@ -334,6 +329,12 @@ class Client(BaseClient):
         DataFrame or Series
             Returns pandas DataFrame with complete list of trade details or if a single
             order ID was specified return a pandas Series with only that trade's details
+
+        See Also
+        --------
+        `order_history`: Obtain comprehensive list of past orders
+        `pull_by_cid`: Pull single trade by KuCoin-generated tradeId.
+        `pull_by_oid`: Pull single trade by user-generated orderId.
         """
         path = f"limit/orders?currentPage={page}&pageSize={pagesize}"
         if id:
@@ -438,9 +439,9 @@ class Client(BaseClient):
             formatting rules and flexibility of param `begin`. If left unspecified, end 
             will default to the current UTC date and time stamp.
         interval : str, optional
-            Interval at which to return OHLCV data. Intervals: `["1min", 
-            "3min", "15min", "30min", "1hour", "2hour", "4hour", "6hour", "8hour", 
-            "12hour", "1day", "1week"]`. Default=1day
+            Interval at which to return OHLCV data. Intervals: `["1min", "3min", "5min",
+            "15min", "30min", "1hour", "2hour", "4hour", "6hour", "8hour", "12hour", "1day",
+            "1week"]`. Default=1day
         ascending : bool, optional
             If `ascending=True`, dataframe will be returned in standard order. If `False`,
             return data in reverse chronological.
@@ -787,7 +788,9 @@ class Client(BaseClient):
         """
         path = f"market/stats?symbol={pair.upper()}"
         resp = self._request("get", path)
-        return pd.Series(resp["data"])
+        ser =  pd.Series(resp["data"])
+        ser.iloc[2:] = ser.iloc[2:].astype(float)
+        return ser
 
     def get_fee_rate(self, currency:str or list or None=None, type:str="crypto") -> dict:
         """Get the base fee for users in either crypto or fiat terms"""
@@ -1268,7 +1271,7 @@ class Client(BaseClient):
 
         Parameters
         ----------
-        currency : str 
+        currency : str
             Specific currency to repay liabilities against (e.g., BTC).
         size : float, optional
             Total sum to repay (in currency terms). Must be a multiple of currency max
@@ -1412,6 +1415,7 @@ class Client(BaseClient):
         if id:
             id = [id] if isinstance(id, str) else id
             res = res[res['tradeId'].isin(id)]
+        res.iloc[:,2:8] = res.iloc[:, 2:8].astype(float)
         return res.set_index('tradeId')
     
     def get_outstanding_loans(
@@ -1678,7 +1682,8 @@ class Client(BaseClient):
                 if not r:
                     r = resp['data'].get("cencelledOrderId")
                 r = [r] if isinstance(r, str) else r
-                responses = responses + r
+                if r:
+                    responses = responses + r
             else:
                 logging.error(
                     "Order cancellation failure: " +
@@ -1690,17 +1695,19 @@ class Client(BaseClient):
 
     def order_history(
         self, symbols:str or list=None, start:str=None, end:str=None, acc_type:str="trade",
-        side:str=None, status:str="done", order_type:str or list=None, consolidated:bool=False,
+        side:str=None, status:str="done", order_type:str or list=None, consolidated:bool=True,
         page:int=None, id:str or list=None, oid:str or list=None, channel:str or list=None,
     ) -> pd.DataFrame:
         """Detailed cross account information on both active and completed orders
 
         This function returns order details in two flavors: Consolidated and unconsolidated. 
-        The consolidated response contains only order price, order size, value of
-        the order portion that was filled, amount of order size that was filled, fees paid, 
-        and relevant asset details. The alternative unconsolidated response contains an 
-        additional 20+ detail columns that will, for most users, not be useful. Use the 
-        `consolidated` argument to toggle between these responses.
+        The consolidated response contains only order price, order size, value of the filled
+        portion, amount of order size that was filled, fees paid, and relevant asset details
+        Unconsolidated responses contain an additional 20+ detail columns that will, for most 
+        users, not be useful. Use the `consolidated` argument to toggle between these responses.
+        Be aware that this endpoint is both slow to run and slow to update. As such, it is not
+        intended for use in performance-oriented algorithms. For significantly faster performance
+        time, use `.pull_by_oid` or `.pull_by_cid` functions.
 
         Parameters
         ----------
@@ -1751,6 +1758,8 @@ class Client(BaseClient):
         See Also
         --------
         * `.recent_orders`: Light-weight function for obtaining orders placed in the last 24-hours
+        * `.pull_by_cid`: Pull a single order execution detail by user-generated OID. High performance function.
+        * `.pull_by_oid`: Pull a single order execution detail by KuCoin-generated OID. High performance function.
         
         Notes
         -----
@@ -1840,6 +1849,7 @@ class Client(BaseClient):
             res = res[res['type'].isin(order_type)]
         if symbols:
             symbols = [symbols] if isinstance(symbols, str) else symbols
+            symbols = [symbol.upper() for symbol in symbols]
             res = res[res['symbol'].isin(symbols)]
         if side:
             res = res[res['side'] == side]
@@ -1859,3 +1869,82 @@ class Client(BaseClient):
         path = f"margin/borrow?orderId={id}"
         resp = self._request("get", path, signed=True)
         return resp
+
+    def pull_by_cid(self, cid:str, unix:bool=True) -> pd.Series:
+        """Pull single order by KuCoin generated OID
+        
+        Parameters
+        ----------
+        cid : str
+            Specify tradeId for target order. tradeId's are autogenerated
+            IDs attached to trades by KuCoin's order matching system.
+        unix : bool, optional
+            Leverage `unix` arguments to specify how to return trade timestamps.
+            If `unix=True` [default] times are returned as UTC unix epoch, else
+            datetimes will be converted to UTC datetime object.
+
+        Returns
+        -------
+        Series
+            Returns pandas Series with trade details
+
+        See Also
+        --------
+        `pull_by_oid`: Pull single trade by user-generated orderId.
+        `order_history`: Obtain comprehensive list of past orders
+        `recent_orders`: Obtain list of order placed in last 24 hours
+        """
+        path = f"order/client-order/{cid}"
+        resp = self._request("get", path, signed=True)
+        try:
+            ser = pd.Series(resp['data'])
+        except KeyError:
+            raise KucoinResponseError(f'No response returned for {cid}')
+        ser.iloc[5:11] = ser.iloc[5:11].astype(float)
+        if not unix:
+            ser.createdAt = pd.to_datetime(ser.createdAt, unit='ms')
+        return ser
+
+    def pull_by_oid(self, oid:str, unix:bool=True) -> pd.Series:
+        """Pull single order by user-generated client OID
+
+        Parameters
+        ----------
+        oid : str
+            Specify tradeId for target order. orderId's are user generated IDs
+            attached to trades via the `oid` argument or `order` when placing an
+            order.
+        unix : bool, optional
+            Leverage `unix` arguments to specify how to return trade timestamps.
+            If `unix=True` [default] times are returned as UTC unix epoch, else
+            datetimes will be converted to UTC datetime object.
+
+        Returns
+        -------
+        Series
+            Returns pandas Series with trade details
+
+        See Also
+        --------
+        `pull_by_cid`: Pull single trade by user-generated orderId.
+        `order_history`: Obtain comprehensive list of past orders
+        `recent_orders`: Obtain list of order placed in last 24 hours
+        """
+        path = f"orders/{oid}"
+        resp = self._request("get", path, signed=True)
+        try:
+            ser = pd.Series(resp['data'])
+        except KeyError:
+            raise KucoinResponseError(f'No response returned for {oid}')
+        ser.iloc[5:11] = ser.iloc[5:11].astype(float)
+        if not unix:
+            ser.createdAt = pd.to_datetime(ser.createdAt, unit='ms')
+        return ser
+
+    def mark_price(self, symbol:str) -> pd.Series:
+        """Get mark price data for a specified symbol"""
+        path = f"mark-price/{symbol.upper()}/current"
+        resp = self._request("get", path)
+        if resp['code'] != '200000':
+            raise KucoinResponseError(resp["msg"])
+        return pd.Series(resp['data'])
